@@ -100,6 +100,11 @@ func TestConvertFromIngressOnOpenShift(t *testing.T) {
 func TestConvertFrom(t *testing.T) {
 	infrastructure.InitializeForTesting(infrastructure.Kubernetes)
 
+	memoryRequest := resource.MustParse("128Mi")
+	cpuRequest := resource.MustParse("1")
+	memoryLimit := resource.MustParse("228Mi")
+	cpuLimit := resource.MustParse("2")
+
 	checlusterv2 := &chev2.CheCluster{
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      "eclipse-che",
@@ -110,45 +115,6 @@ func TestConvertFrom(t *testing.T) {
 				Metrics: chev2.ServerMetrics{
 					Enable: true,
 				},
-				Database: chev2.Database{
-					ExternalDb: true,
-					Deployment: &chev2.Deployment{
-						Containers: []chev2.Container{
-							{
-								Image:           "DatabaseImage",
-								ImagePullPolicy: corev1.PullAlways,
-								Resources: &chev2.ResourceRequirements{
-									Requests: &chev2.ResourceList{
-										Memory: resource.MustParse("128Mi"),
-										Cpu:    resource.MustParse("1"),
-									},
-									Limits: &chev2.ResourceList{
-										Memory: resource.MustParse("228Mi"),
-										Cpu:    resource.MustParse("2"),
-									},
-								},
-								Env: []corev1.EnvVar{
-									{
-										Name:  "database-name",
-										Value: "database-value",
-									},
-								},
-							},
-						},
-						SecurityContext: &chev2.PodSecurityContext{
-							RunAsUser: pointer.Int64Ptr(64),
-							FsGroup:   pointer.Int64Ptr(65),
-						},
-					},
-					PostgresHostName:      "PostgresHostName",
-					PostgresPort:          "PostgresPort",
-					PostgresDb:            "PostgresDb",
-					CredentialsSecretName: "DatabaseCredentialsSecretName",
-					Pvc: &chev2.PVC{
-						ClaimSize:    "DatabaseClaimSize",
-						StorageClass: "DatabaseStorageClass",
-					},
-				},
 				PluginRegistry: chev2.PluginRegistry{
 					Deployment: &chev2.Deployment{
 						Containers: []chev2.Container{
@@ -157,12 +123,12 @@ func TestConvertFrom(t *testing.T) {
 								ImagePullPolicy: corev1.PullAlways,
 								Resources: &chev2.ResourceRequirements{
 									Requests: &chev2.ResourceList{
-										Memory: resource.MustParse("128Mi"),
-										Cpu:    resource.MustParse("1"),
+										Memory: &memoryRequest,
+										Cpu:    &cpuRequest,
 									},
 									Limits: &chev2.ResourceList{
-										Memory: resource.MustParse("228Mi"),
-										Cpu:    resource.MustParse("2"),
+										Memory: &memoryLimit,
+										Cpu:    &cpuLimit,
 									},
 								},
 								Env: []corev1.EnvVar{
@@ -197,14 +163,13 @@ func TestConvertFrom(t *testing.T) {
 								ImagePullPolicy: corev1.PullAlways,
 								Resources: &chev2.ResourceRequirements{
 									Requests: &chev2.ResourceList{
-										Memory: resource.MustParse("128Mi"),
-										Cpu:    resource.MustParse("1"),
+										Memory: &memoryRequest,
+										Cpu:    &cpuRequest,
 									},
 									Limits: &chev2.ResourceList{
-										Memory: resource.MustParse("228Mi"),
-										Cpu:    resource.MustParse("2"),
-									},
-								},
+										Memory: &memoryLimit,
+										Cpu:    &cpuLimit,
+									}},
 								Env: []corev1.EnvVar{
 									{
 										Name:  "devfile-registry-name",
@@ -233,12 +198,12 @@ func TestConvertFrom(t *testing.T) {
 								ImagePullPolicy: corev1.PullAlways,
 								Resources: &chev2.ResourceRequirements{
 									Requests: &chev2.ResourceList{
-										Memory: resource.MustParse("128Mi"),
-										Cpu:    resource.MustParse("1"),
+										Memory: &memoryRequest,
+										Cpu:    &cpuRequest,
 									},
 									Limits: &chev2.ResourceList{
-										Memory: resource.MustParse("228Mi"),
-										Cpu:    resource.MustParse("2"),
+										Memory: &memoryLimit,
+										Cpu:    &cpuLimit,
 									},
 								},
 								Env: []corev1.EnvVar{
@@ -271,12 +236,12 @@ func TestConvertFrom(t *testing.T) {
 								ImagePullPolicy: corev1.PullAlways,
 								Resources: &chev2.ResourceRequirements{
 									Requests: &chev2.ResourceList{
-										Memory: resource.MustParse("128Mi"),
-										Cpu:    resource.MustParse("1"),
+										Memory: &memoryRequest,
+										Cpu:    &cpuRequest,
 									},
 									Limits: &chev2.ResourceList{
-										Memory: resource.MustParse("228Mi"),
-										Cpu:    resource.MustParse("2"),
+										Memory: &memoryLimit,
+										Cpu:    &cpuLimit,
 									},
 								},
 								Env: []corev1.EnvVar{
@@ -408,19 +373,16 @@ func TestConvertFrom(t *testing.T) {
 				GitHub: []chev2.GitHubService{
 					{
 						SecretName: "github-secret-name",
-						Endpoint:   "github-endpoint",
 					},
 				},
 				GitLab: []chev2.GitLabService{
 					{
 						SecretName: "gitlab-secret-name",
-						Endpoint:   "gitlab-endpoint",
 					},
 				},
 				BitBucket: []chev2.BitBucketService{
 					{
 						SecretName: "bitbucket-secret-name",
-						Endpoint:   "bitbucket-endpoint",
 					},
 				},
 			},
@@ -433,7 +395,6 @@ func TestConvertFrom(t *testing.T) {
 			ChePhase:           "Active",
 			Message:            "Message",
 			Reason:             "Reason",
-			PostgresVersion:    "PostgresVersion",
 		},
 	}
 
@@ -469,22 +430,6 @@ func TestConvertFrom(t *testing.T) {
 	assert.Equal(t, checlusterv1.Spec.Auth.GatewayConfigBumpEnv[0].Name, "configbump-name")
 	assert.Equal(t, checlusterv1.Spec.Auth.GatewayConfigBumpEnv[0].Value, "configbump-value")
 
-	assert.Equal(t, checlusterv1.Spec.Database.ChePostgresContainerResources.Limits.Cpu, "2")
-	assert.Equal(t, checlusterv1.Spec.Database.ChePostgresContainerResources.Limits.Memory, "228Mi")
-	assert.Equal(t, checlusterv1.Spec.Database.ChePostgresContainerResources.Requests.Cpu, "1")
-	assert.Equal(t, checlusterv1.Spec.Database.ChePostgresContainerResources.Requests.Memory, "128Mi")
-	assert.Equal(t, checlusterv1.Spec.Database.ChePostgresDb, "PostgresDb")
-	assert.Equal(t, checlusterv1.Spec.Database.ChePostgresHostName, "PostgresHostName")
-	assert.Equal(t, checlusterv1.Spec.Database.ChePostgresPort, "PostgresPort")
-	assert.Equal(t, checlusterv1.Spec.Database.ChePostgresSecret, "DatabaseCredentialsSecretName")
-	assert.Equal(t, checlusterv1.Spec.Database.ExternalDb, true)
-	assert.Equal(t, checlusterv1.Spec.Database.PostgresImage, "DatabaseImage")
-	assert.Equal(t, checlusterv1.Spec.Database.PostgresImagePullPolicy, corev1.PullAlways)
-	assert.Equal(t, checlusterv1.Spec.Database.PostgresVersion, "PostgresVersion")
-	assert.Equal(t, checlusterv1.Spec.Database.PvcClaimSize, "DatabaseClaimSize")
-	assert.Equal(t, checlusterv1.Spec.Database.PostgresEnv[0].Name, "database-name")
-	assert.Equal(t, checlusterv1.Spec.Database.PostgresEnv[0].Value, "database-value")
-
 	assert.Equal(t, checlusterv1.Spec.DevWorkspace.RunningLimit, "10")
 	assert.Equal(t, checlusterv1.Spec.DevWorkspace.SecondsOfInactivityBeforeIdling, pointer.Int32Ptr(1800))
 	assert.Equal(t, checlusterv1.Spec.DevWorkspace.SecondsOfRunBeforeIdling, pointer.Int32Ptr(-1))
@@ -563,23 +508,22 @@ func TestConvertFrom(t *testing.T) {
 	assert.Equal(t, checlusterv1.Spec.Server.WorkspacesDefaultPlugins, []chev1.WorkspacesDefaultPlugins{{Editor: "Editor", Plugins: []string{"Plugins_1", "Plugins_2"}}})
 
 	assert.Equal(t, checlusterv1.Spec.Storage.PvcStrategy, "PvcStrategy")
-	assert.Equal(t, checlusterv1.Spec.Storage.PostgresPVCStorageClassName, "DatabaseStorageClass")
 	assert.Equal(t, checlusterv1.Spec.Storage.PvcClaimSize, "StorageClaimSize")
 	assert.Equal(t, checlusterv1.Spec.Storage.WorkspacePVCStorageClassName, "StorageClass")
 	assert.Equal(t, checlusterv1.Spec.Storage.PerWorkspaceStrategyPvcClaimSize, "PerWorkspaceStorageClaimSize")
 	assert.Equal(t, checlusterv1.Spec.Storage.PerWorkspaceStrategyPVCStorageClassName, "PerWorkspaceStorageClass")
 
 	assert.Equal(t, checlusterv1.Spec.GitServices.GitHub[0].SecretName, "github-secret-name")
-	assert.Equal(t, checlusterv1.Spec.GitServices.GitHub[0].Endpoint, "github-endpoint")
 	assert.Equal(t, checlusterv1.Spec.GitServices.GitLab[0].SecretName, "gitlab-secret-name")
-	assert.Equal(t, checlusterv1.Spec.GitServices.GitLab[0].Endpoint, "gitlab-endpoint")
 	assert.Equal(t, checlusterv1.Spec.GitServices.BitBucket[0].SecretName, "bitbucket-secret-name")
-	assert.Equal(t, checlusterv1.Spec.GitServices.BitBucket[0].Endpoint, "bitbucket-endpoint")
 }
 
 func TestShouldConvertFromWhenOnlyMemoryResourceSpecified(t *testing.T) {
 	infrastructure.InitializeForTesting(infrastructure.OpenShiftv4)
 
+	memoryRequest := resource.MustParse("128Mi")
+	memoryLimit := resource.MustParse("228Mi")
+
 	checlusterv2 := &chev2.CheCluster{
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      "eclipse-che",
@@ -593,10 +537,10 @@ func TestShouldConvertFromWhenOnlyMemoryResourceSpecified(t *testing.T) {
 							{
 								Resources: &chev2.ResourceRequirements{
 									Requests: &chev2.ResourceList{
-										Memory: resource.MustParse("128Mi"),
+										Memory: &memoryRequest,
 									},
 									Limits: &chev2.ResourceList{
-										Memory: resource.MustParse("228Mi"),
+										Memory: &memoryLimit,
 									},
 								},
 							},
