@@ -74,6 +74,11 @@ func TestRoundConvertEmptyCheClusterV1(t *testing.T) {
 }
 
 func TestRoundConvertCheClusterV2(t *testing.T) {
+	memoryRequest := resource.MustParse("148Mi")
+	cpuRequest := resource.MustParse("1")
+	memoryLimit := resource.MustParse("228Mi")
+	cpuLimit := resource.MustParse("2")
+
 	f := func() {
 		checlusterv2Original := &chev2.CheCluster{
 			ObjectMeta: metav1.ObjectMeta{
@@ -85,36 +90,6 @@ func TestRoundConvertCheClusterV2(t *testing.T) {
 					Metrics: chev2.ServerMetrics{
 						Enable: true,
 					},
-					Database: chev2.Database{
-						ExternalDb: true,
-						Deployment: &chev2.Deployment{
-							Containers: []chev2.Container{
-								{
-									Name:            "postgres",
-									Image:           "DatabaseImage",
-									ImagePullPolicy: corev1.PullAlways,
-									Resources: &chev2.ResourceRequirements{
-										Requests: &chev2.ResourceList{
-											Memory: resource.MustParse("148Mi"),
-											Cpu:    resource.MustParse("1"),
-										},
-										Limits: &chev2.ResourceList{
-											Memory: resource.MustParse("228Mi"),
-											Cpu:    resource.MustParse("2"),
-										},
-									},
-								},
-							},
-						},
-						PostgresHostName:      "PostgresHostName",
-						PostgresPort:          "PostgresPort",
-						PostgresDb:            "PostgresDb",
-						CredentialsSecretName: "DatabaseCredentialsSecretName",
-						Pvc: &chev2.PVC{
-							ClaimSize:    "DatabaseClaimSize",
-							StorageClass: "DatabaseStorageClass",
-						},
-					},
 					PluginRegistry: chev2.PluginRegistry{
 						Deployment: &chev2.Deployment{
 							Containers: []chev2.Container{
@@ -124,12 +99,12 @@ func TestRoundConvertCheClusterV2(t *testing.T) {
 									ImagePullPolicy: corev1.PullAlways,
 									Resources: &chev2.ResourceRequirements{
 										Requests: &chev2.ResourceList{
-											Memory: resource.MustParse("148Mi"),
-											Cpu:    resource.MustParse("1"),
+											Memory: &memoryRequest,
+											Cpu:    &cpuRequest,
 										},
 										Limits: &chev2.ResourceList{
-											Memory: resource.MustParse("228Mi"),
-											Cpu:    resource.MustParse("2"),
+											Memory: &memoryLimit,
+											Cpu:    &cpuLimit,
 										},
 									},
 								},
@@ -151,12 +126,12 @@ func TestRoundConvertCheClusterV2(t *testing.T) {
 									ImagePullPolicy: corev1.PullAlways,
 									Resources: &chev2.ResourceRequirements{
 										Requests: &chev2.ResourceList{
-											Memory: resource.MustParse("148Mi"),
-											Cpu:    resource.MustParse("1"),
+											Memory: &memoryRequest,
+											Cpu:    &cpuRequest,
 										},
 										Limits: &chev2.ResourceList{
-											Memory: resource.MustParse("228Mi"),
-											Cpu:    resource.MustParse("2"),
+											Memory: &memoryLimit,
+											Cpu:    &cpuLimit,
 										},
 									},
 								},
@@ -178,12 +153,12 @@ func TestRoundConvertCheClusterV2(t *testing.T) {
 									ImagePullPolicy: corev1.PullAlways,
 									Resources: &chev2.ResourceRequirements{
 										Requests: &chev2.ResourceList{
-											Memory: resource.MustParse("148Mi"),
-											Cpu:    resource.MustParse("1"),
+											Memory: &memoryRequest,
+											Cpu:    &cpuRequest,
 										},
 										Limits: &chev2.ResourceList{
-											Memory: resource.MustParse("228Mi"),
-											Cpu:    resource.MustParse("2"),
+											Memory: &memoryLimit,
+											Cpu:    &cpuLimit,
 										},
 									},
 								},
@@ -211,12 +186,12 @@ func TestRoundConvertCheClusterV2(t *testing.T) {
 									ImagePullPolicy: corev1.PullAlways,
 									Resources: &chev2.ResourceRequirements{
 										Requests: &chev2.ResourceList{
-											Memory: resource.MustParse("148Mi"),
-											Cpu:    resource.MustParse("1"),
+											Memory: &memoryRequest,
+											Cpu:    &cpuRequest,
 										},
 										Limits: &chev2.ResourceList{
-											Memory: resource.MustParse("228Mi"),
-											Cpu:    resource.MustParse("2"),
+											Memory: &memoryLimit,
+											Cpu:    &cpuLimit,
 										},
 									},
 								},
@@ -320,7 +295,6 @@ func TestRoundConvertCheClusterV2(t *testing.T) {
 				ChePhase:           "Active",
 				Message:            "Message",
 				Reason:             "Reason",
-				PostgresVersion:    "PostgresVersion",
 			},
 		}
 
