@@ -45,10 +45,6 @@ func (dst *CheCluster) ConvertFrom(srcRaw conversion.Hub) error {
 		return err
 	}
 
-	if err := dst.convertFrom_Database(src); err != nil {
-		return err
-	}
-
 	if err := dst.convertFrom_DevWorkspace(src); err != nil {
 		return err
 	}
@@ -86,7 +82,6 @@ func (dst *CheCluster) convertFrom_GitServices(src *chev2.CheCluster) error {
 			dst.Spec.GitServices.GitHub,
 			GitHubService{
 				SecretName: github.SecretName,
-				Endpoint:   github.Endpoint,
 			})
 	}
 
@@ -95,7 +90,6 @@ func (dst *CheCluster) convertFrom_GitServices(src *chev2.CheCluster) error {
 			dst.Spec.GitServices.GitLab,
 			GitLabService{
 				SecretName: gitlab.SecretName,
-				Endpoint:   gitlab.Endpoint,
 			})
 	}
 
@@ -104,7 +98,6 @@ func (dst *CheCluster) convertFrom_GitServices(src *chev2.CheCluster) error {
 			dst.Spec.GitServices.BitBucket,
 			BitBucketService{
 				SecretName: bitbucket.SecretName,
-				Endpoint:   bitbucket.Endpoint,
 			})
 	}
 
@@ -352,38 +345,6 @@ func (dst *CheCluster) convertFrom_Auth(src *chev2.CheCluster) error {
 	return nil
 }
 
-func (dst *CheCluster) convertFrom_Database(src *chev2.CheCluster) error {
-	dst.Spec.Database.ExternalDb = src.Spec.Components.Database.ExternalDb
-	dst.Spec.Database.ChePostgresDb = src.Spec.Components.Database.PostgresDb
-	dst.Spec.Database.ChePostgresHostName = src.Spec.Components.Database.PostgresHostName
-	dst.Spec.Database.ChePostgresPort = src.Spec.Components.Database.PostgresPort
-	dst.Spec.Database.PostgresVersion = src.Status.PostgresVersion
-	if src.Spec.Components.Database.Pvc != nil {
-		dst.Spec.Database.PvcClaimSize = src.Spec.Components.Database.Pvc.ClaimSize
-	}
-	dst.Spec.Database.ChePostgresSecret = src.Spec.Components.Database.CredentialsSecretName
-
-	if src.Spec.Components.Database.Deployment != nil {
-		if len(src.Spec.Components.Database.Deployment.Containers) != 0 {
-			dst.Spec.Database.PostgresEnv = src.Spec.Components.Database.Deployment.Containers[0].Env
-			dst.Spec.Database.PostgresImage = src.Spec.Components.Database.Deployment.Containers[0].Image
-			dst.Spec.Database.PostgresImagePullPolicy = src.Spec.Components.Database.Deployment.Containers[0].ImagePullPolicy
-			if src.Spec.Components.Database.Deployment.Containers[0].Resources != nil {
-				if src.Spec.Components.Database.Deployment.Containers[0].Resources.Requests != nil {
-					dst.Spec.Database.ChePostgresContainerResources.Requests.Memory = resource2String(src.Spec.Components.Database.Deployment.Containers[0].Resources.Requests.Memory)
-					dst.Spec.Database.ChePostgresContainerResources.Requests.Cpu = resource2String(src.Spec.Components.Database.Deployment.Containers[0].Resources.Requests.Cpu)
-				}
-				if src.Spec.Components.Database.Deployment.Containers[0].Resources.Limits != nil {
-					dst.Spec.Database.ChePostgresContainerResources.Limits.Memory = resource2String(src.Spec.Components.Database.Deployment.Containers[0].Resources.Limits.Memory)
-					dst.Spec.Database.ChePostgresContainerResources.Limits.Cpu = resource2String(src.Spec.Components.Database.Deployment.Containers[0].Resources.Limits.Cpu)
-				}
-			}
-		}
-	}
-
-	return nil
-}
-
 func (dst *CheCluster) convertFrom_DevWorkspace(src *chev2.CheCluster) error {
 	if src.Spec.DevEnvironments.MaxNumberOfRunningWorkspacesPerUser != nil {
 		dst.Spec.DevWorkspace.RunningLimit = strconv.FormatInt(*src.Spec.DevEnvironments.MaxNumberOfRunningWorkspacesPerUser, 10)
@@ -446,10 +407,6 @@ func (dst *CheCluster) convertFrom_Status(src *chev2.CheCluster) error {
 }
 
 func (dst *CheCluster) convertFrom_Storage(src *chev2.CheCluster) error {
-	if src.Spec.Components.Database.Pvc != nil {
-		dst.Spec.Storage.PostgresPVCStorageClassName = src.Spec.Components.Database.Pvc.StorageClass
-	}
-
 	dst.Spec.Storage.PvcStrategy = src.Spec.DevEnvironments.Storage.PvcStrategy
 	if src.Spec.DevEnvironments.Storage.PerUserStrategyPvcConfig != nil {
 		dst.Spec.Storage.PvcClaimSize = src.Spec.DevEnvironments.Storage.PerUserStrategyPvcConfig.ClaimSize
@@ -477,8 +434,8 @@ func findTrustStoreConfigMap(namespace string) (string, error) {
 	return "", nil
 }
 
-func resource2String(resource resource.Quantity) string {
-	if resource.IsZero() {
+func resource2String(resource *resource.Quantity) string {
+	if resource == nil || resource.IsZero() {
 		return ""
 	}
 	return resource.String()
