@@ -16,12 +16,17 @@ package v2
 // to regenerate `api/v2/zz_generatedxxx` code after modifying this file.
 
 import (
-	"os"
+	"strconv"
 	"strings"
 
+	ctrl "sigs.k8s.io/controller-runtime"
+
+	defaults "github.com/eclipse-che/che-operator/pkg/common/operator-defaults"
+
 	"github.com/devfile/devworkspace-operator/pkg/infrastructure"
 	"github.com/eclipse-che/che-operator/pkg/common/constants"
 
+	controllerv1alpha1 "github.com/devfile/devworkspace-operator/apis/controller/v1alpha1"
 	"k8s.io/apimachinery/pkg/api/resource"
 
 	imagepullerv1alpha1 "github.com/che-incubator/kubernetes-image-puller-operator/api/v1alpha1"
@@ -30,6 +35,8 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
 
+var logger = ctrl.Log.WithName("checluster")
+
 // +k8s:openapi-gen=true
 // Desired configuration of Eclipse Che installation.
 type CheClusterSpec struct {
@@ -37,13 +44,13 @@ type CheClusterSpec struct {
 	// +optional
 	// +operator-sdk:csv:customresourcedefinitions:type=spec,order=1
 	// +operator-sdk:csv:customresourcedefinitions:type=spec,displayName="Development environments"
-	// +kubebuilder:default:={disableContainerBuildCapabilities: true, defaultComponents: {{name: universal-developer-image, container: {image: "quay.io/devfile/universal-developer-image:ubi8-38da5c2"}}}, defaultEditor: che-incubator/che-code/latest, storage: {pvcStrategy: per-user}, defaultNamespace: {template: <username>-devspaces, autoProvision: true}, secondsOfInactivityBeforeIdling:1800, secondsOfRunBeforeIdling:-1, startTimeoutSeconds:300, maxNumberOfWorkspacesPerUser:-1}
+	// +kubebuilder:default:={storage: {pvcStrategy: per-user}, defaultNamespace: {template: <username>-devspaces, autoProvision: true}, secondsOfInactivityBeforeIdling:1800, secondsOfRunBeforeIdling:-1, startTimeoutSeconds:300, maxNumberOfWorkspacesPerUser:-1}
 	DevEnvironments CheClusterDevEnvironments `json:"devEnvironments"`
 	// Che components configuration.
 	// +optional
 	// +operator-sdk:csv:customresourcedefinitions:type=spec,order=2
 	// +operator-sdk:csv:customresourcedefinitions:type=spec,displayName="Components"
-	// +kubebuilder:default:={cheServer: {logLevel: INFO, debug: false}, metrics: {enable: true}, database: {externalDb: false, credentialsSecretName: postgres-credentials, postgresHostName: postgres, postgresPort: "5432", postgresDb: dbche, pvc: {claimSize: "1Gi"}}}
+	// +kubebuilder:default:={cheServer: {logLevel: INFO, debug: false}, metrics: {enable: true}}
 	Components CheClusterComponents `json:"components"`
 	// A configuration that allows users to work with remote Git repositories.
 	// +optional
@@ -90,12 +97,10 @@ type CheClusterDevEnvironments struct {
 	// The plugin ID must have `publisher/plugin/version` format.
 	// The URI must start from `http://` or `https://`.
 	// +optional
-	// +kubebuilder:default:=che-incubator/che-code/latest
 	DefaultEditor string `json:"defaultEditor,omitempty"`
 	// Default components applied to DevWorkspaces.
 	// These default components are meant to be used when a Devfile, that does not contain any components.
 	// +optional
-	// +kubebuilder:default:={{name: universal-developer-image, container: {image: "quay.io/devfile/universal-developer-image:ubi8-38da5c2"}}}
 	DefaultComponents []devfile.Component `json:"defaultComponents,omitempty"`
 	// Idle timeout for workspaces in seconds.
 	// This timeout is the duration after which a workspace will be idled if there is no activity.
@@ -109,7 +114,6 @@ type CheClusterDevEnvironments struct {
 	SecondsOfRunBeforeIdling *int32 `json:"secondsOfRunBeforeIdling,omitempty"`
 	// Disables the container build capabilities.
 	// +optional
-	// +kubebuilder:default:=true
 	DisableContainerBuildCapabilities *bool `json:"disableContainerBuildCapabilities,omitempty"`
 	// Container build configuration.
 	// +optional
@@ -119,6 +123,9 @@ type CheClusterDevEnvironments struct {
 	// +kubebuilder:validation:Pattern=^[a-z0-9]([-a-z0-9]*[a-z0-9])?$
 	// +kubebuilder:validation:MaxLength=63
 	ServiceAccount string `json:"serviceAccount,omitempty"`
+	// List of ServiceAccount tokens that will be mounted into workspace pods as projected volumes.
+	// +optional
+	ServiceAccountTokens []controllerv1alpha1.ServiceAccountToken `json:"serviceAccountTokens,omitempty"`
 	// Pod scheduler for the workspace pods.
 	// If not specified, the pod scheduler is set to the default scheduler on the cluster.
 	// +optional
@@ -160,8 +167,9 @@ type CheClusterComponents struct {
 	// +optional
 	DevfileRegistry DevfileRegistry `json:"devfileRegistry"`
 	// Configuration settings related to the database used by the Che installation.
+	// Database component is Deprecated. All properties will be ignored.
 	// +optional
-	// +kubebuilder:default:={externalDb: false, credentialsSecretName: postgres-credentials, postgresHostName: postgres, postgresPort: "5432", postgresDb: dbche, pvc: {claimSize: "1Gi"}}
+	// +operator-sdk:csv:customresourcedefinitions:type=spec,xDescriptors="urn:alm:descriptor:com.tectonic.ui:hidden"
 	Database Database `json:"database"`
 	// Configuration settings related to the dashboard used by the Che installation.
 	// +optional
@@ -302,6 +310,7 @@ type DevfileRegistry struct {
 	ExternalDevfileRegistries []ExternalDevfileRegistry `json:"externalDevfileRegistries,omitempty"`
 }
 
+// Database component is Deprecated. All properties will be ignored.
 // Configuration settings related to the database used by the Che installation.
 // +k8s:openapi-gen=true
 type Database struct {
@@ -310,33 +319,27 @@ type Database struct {
 	// When `externalDb` is set as `true`, no dedicated database is deployed by the
 	// Operator and you need to provide connection details about the external database you want to use.
 	// +optional
-	// +kubebuilder:default:=false
 	ExternalDb bool `json:"externalDb"`
 	// Deployment override options.
 	// +optional
 	Deployment *Deployment `json:"deployment,omitempty"`
 	// PostgreSQL database hostname that the Che server connects to.
 	// Override this value only when using an external database. See field `externalDb`.
-	// +kubebuilder:default:="postgres"
 	// +optional
 	PostgresHostName string `json:"postgresHostName,omitempty"`
 	// PostgreSQL Database port the Che server connects to.
 	// Override this value only when using an external database. See field `externalDb`.
 	// +optional
-	// +kubebuilder:default:="5432"
 	PostgresPort string `json:"postgresPort,omitempty"`
 	// PostgreSQL database name that the Che server uses to connect to the database.
 	// +optional
-	// +kubebuilder:default:="dbche"
 	PostgresDb string `json:"postgresDb,omitempty"`
 	// The secret that contains PostgreSQL `user` and `password` that the Che server uses to connect to the database.
 	// The secret must have a `app.kubernetes.io/part-of=che.eclipse.org` label.
 	// +optional
-	// +kubebuilder:default:="postgres-credentials"
 	CredentialsSecretName string `json:"credentialsSecretName,omitempty"`
 	// PVC settings for PostgreSQL database.
 	// +optional
-	// +kubebuilder:default:={claimSize: "1Gi"}
 	Pvc *PVC `json:"pvc,omitempty"`
 }
 
@@ -579,11 +582,15 @@ type ResourceRequirements struct {
 // List of resources.
 type ResourceList struct {
 	// Memory, in bytes. (500Gi = 500GiB = 500 * 1024 * 1024 * 1024)
+	// If the value is not specified, then the default value is set depending on the component.
+	// If value is `0`, then no value is set for the component.
 	// +optional
-	Memory resource.Quantity `json:"memory,omitempty"`
+	Memory *resource.Quantity `json:"memory,omitempty"`
 	// CPU, in cores. (500m = .5 cores)
+	// If the value is not specified, then the default value is set depending on the component.
+	// If value is `0`, then no value is set for the component.
 	// +optional
-	Cpu resource.Quantity `json:"cpu,omitempty"`
+	Cpu *resource.Quantity `json:"cpu,omitempty"`
 }
 
 // PodSecurityContext holds pod-level security attributes and common container settings.
@@ -617,50 +624,49 @@ type CheClusterGitServices struct {
 
 // GitHubService enables users to work with repositories hosted on GitHub (GitHub.com or GitHub Enterprise).
 type GitHubService struct {
-	// Kubernetes secret, that contains Base64-encoded GitHub OAuth Client id and GitHub OAuth Client secret,
-	// that stored in `id` and `secret` keys respectively.
-	// See the following page: https://www.eclipse.org/che/docs/stable/administration-guide/configuring-oauth-2-for-github/.
+	// Kubernetes secret, that contains Base64-encoded GitHub OAuth Client id and GitHub OAuth Client secret.
+	// See the following page for details: https://www.eclipse.org/che/docs/stable/administration-guide/configuring-oauth-2-for-github/.
 	// +kubebuilder:validation:Required
 	// +operator-sdk:csv:customresourcedefinitions:type=spec,xDescriptors="urn:alm:descriptor:io.kubernetes:Secret"
 	SecretName string `json:"secretName"`
 	// GitHub server endpoint URL.
-	// +kubebuilder:validation:Required
-	// +kubebuilder:default:="https://github.com"
-	Endpoint string `json:"endpoint"`
+	// Deprecated in favor of `che.eclipse.org/scm-server-endpoint` annotation.
+	// See the following page for details: https://www.eclipse.org/che/docs/stable/administration-guide/configuring-oauth-2-for-github/.
+	// +optional
+	Endpoint string `json:"endpoint,omitempty"`
 	// Disables subdomain isolation.
+	// Deprecated in favor of `che.eclipse.org/scm-github-disable-subdomain-isolation` annotation.
+	// See the following page for details: https://www.eclipse.org/che/docs/stable/administration-guide/configuring-oauth-2-for-github/.
 	// +optional
 	DisableSubdomainIsolation *bool `json:"disableSubdomainIsolation,omitempty"`
 }
 
 // GitLabService enables users to work with repositories hosted on GitLab (gitlab.com or self-hosted).
 type GitLabService struct {
-	// Kubernetes secret, that contains Base64-encoded GitHub Application id and GitLab Application Client secret,
-	// that stored in `id` and `secret` keys respectively.
+	// Kubernetes secret, that contains Base64-encoded GitHub Application id and GitLab Application Client secret.
 	// See the following page: https://www.eclipse.org/che/docs/stable/administration-guide/configuring-oauth-2-for-gitlab/.
 	// +kubebuilder:validation:Required
 	// +operator-sdk:csv:customresourcedefinitions:type=spec,xDescriptors="urn:alm:descriptor:io.kubernetes:Secret"
 	SecretName string `json:"secretName"`
 	// GitLab server endpoint URL.
-	// +kubebuilder:validation:Required
-	// +kubebuilder:default:="https://gitlab.com"
-	Endpoint string `json:"endpoint"`
+	// Deprecated in favor of `che.eclipse.org/scm-server-endpoint` annotation.
+	// See the following page: https://www.eclipse.org/che/docs/stable/administration-guide/configuring-oauth-2-for-gitlab/.
+	// +optional
+	Endpoint string `json:"endpoint,omitempty"`
 }
 
 // BitBucketService enables users to work with repositories hosted on Bitbucket (bitbucket.org or self-hosted).
 type BitBucketService struct {
 	// Kubernetes secret, that contains Base64-encoded Bitbucket OAuth 1.0 or OAuth 2.0 data.
-	// For OAuth 1.0: private key, Bitbucket Application link consumer key and Bitbucket Application link shared secret must be stored
-	// in `private.key`, `consumer.key` and `shared_secret` keys respectively.
-	// See the following page: https://www.eclipse.org/che/docs/stable/administration-guide/configuring-oauth-1-for-a-bitbucket-server/.
-	// For OAuth 2.0: Bitbucket OAuth consumer key and Bitbucket OAuth consumer secret must be stored
-	// in `id` and `secret` keys respectively.
-	// See the following page: https://www.eclipse.org/che/docs/stable/administration-guide/configuring-oauth-2-for-the-bitbucket-cloud/.
+	// See the following pages for details: https://www.eclipse.org/che/docs/stable/administration-guide/configuring-oauth-1-for-a-bitbucket-server/
+	// and https://www.eclipse.org/che/docs/stable/administration-guide/configuring-oauth-2-for-the-bitbucket-cloud/.
 	// +kubebuilder:validation:Required
 	// +operator-sdk:csv:customresourcedefinitions:type=spec,xDescriptors="urn:alm:descriptor:io.kubernetes:Secret"
 	SecretName string `json:"secretName"`
 	// Bitbucket server endpoint URL.
-	// +kubebuilder:validation:Required
-	// +kubebuilder:default:="https://bitbucket.org"
+	// Deprecated in favor of `che.eclipse.org/scm-server-endpoint` annotation.
+	// See the following page: https://www.eclipse.org/che/docs/stable/administration-guide/configuring-oauth-1-for-a-bitbucket-server/.
+	// +optional
 	Endpoint string `json:"endpoint,omitempty"`
 }
 
@@ -755,6 +761,7 @@ type CheClusterStatus struct {
 	// +operator-sdk:csv:customresourcedefinitions:type=status
 	// +operator-sdk:csv:customresourcedefinitions:type=status,displayName="PostgreSQL version"
 	// +operator-sdk:csv:customresourcedefinitions:type=status,xDescriptors="urn:alm:descriptor:text"
+	// +operator-sdk:csv:customresourcedefinitions:type=status,xDescriptors="urn:alm:descriptor:com.tectonic.ui:hidden"
 	PostgresVersion string `json:"postgresVersion,omitempty"`
 	// The resolved workspace base domain. This is either the copy of the explicitly defined property of the
 	// same name in the spec or, if it is undefined in the spec and we're running on OpenShift, the automatically
@@ -829,7 +836,7 @@ func (c *CheCluster) GetDefaultNamespace() string {
 		return c.Spec.DevEnvironments.DefaultNamespace.Template
 	}
 
-	return "<username>-" + os.Getenv("CHE_FLAVOR")
+	return "<username>-" + defaults.GetCheFlavor()
 }
 
 func (c *CheCluster) GetIdentityToken() string {
@@ -847,8 +854,20 @@ func (c *CheCluster) IsAccessTokenConfigured() bool {
 	return c.GetIdentityToken() == constants.AccessToken
 }
 
+// IsContainerBuildCapabilitiesEnabled returns true if container build capabilities are enabled.
+// If value is not set in the CheCluster CR, then the default value is used.
 func (c *CheCluster) IsContainerBuildCapabilitiesEnabled() bool {
-	return c.Spec.DevEnvironments.DisableContainerBuildCapabilities != nil && !*c.Spec.DevEnvironments.DisableContainerBuildCapabilities
+	disableContainerBuildCapabilitiesParsed, err := strconv.ParseBool(defaults.GetDevEnvironmentsDisableContainerBuildCapabilities())
+	if err != nil {
+		logger.Error(err, "Failed to parse disableContainerBuildCapabilities", "value", disableContainerBuildCapabilitiesParsed)
+		return false
+	}
+
+	if c.Spec.DevEnvironments.DisableContainerBuildCapabilities != nil {
+		disableContainerBuildCapabilitiesParsed = *c.Spec.DevEnvironments.DisableContainerBuildCapabilities
+	}
+
+	return !disableContainerBuildCapabilitiesParsed
 }
 
 func (c *CheCluster) IsOpenShiftSecurityContextConstraintSet() bool {
@@ -856,9 +875,15 @@ func (c *CheCluster) IsOpenShiftSecurityContextConstraintSet() bool {
 }
 
 func (c *CheCluster) IsCheFlavor() bool {
-	return os.Getenv("CHE_FLAVOR") == constants.CheFlavor
+	return defaults.GetCheFlavor() == constants.CheFlavor
 }
 
-func (c *CheCluster) IsOpenVSXURLEmpty() bool {
-	return c.Spec.Components.PluginRegistry.OpenVSXURL == nil || *c.Spec.Components.PluginRegistry.OpenVSXURL == ""
+// IsEmbeddedOpenVSXRegistryConfigured returns true if the Open VSX Registry is configured to be embedded
+// only if only the `Spec.Components.PluginRegistry.OpenVSXURL` is empty.
+func (c *CheCluster) IsEmbeddedOpenVSXRegistryConfigured() bool {
+	openVSXURL := defaults.GetPluginRegistryOpenVSXURL()
+	if c.Spec.Components.PluginRegistry.OpenVSXURL != nil {
+		openVSXURL = *c.Spec.Components.PluginRegistry.OpenVSXURL
+	}
+	return openVSXURL == ""
 }
