@@ -302,14 +302,15 @@ func TestCreateRelocatedObjectsK8S(t *testing.T) {
 
 		workspaceMainConfig := gateway.TraefikConfig{}
 		assert.NoError(t, yaml.Unmarshal([]byte(traefikMainWorkspaceConfig), &workspaceMainConfig))
-		assert.Len(t, workspaceMainConfig.HTTP.Middlewares, 4)
+		assert.Len(t, workspaceMainConfig.HTTP.Middlewares, 5)
 
 		wsid = "wsid"
 		mwares = []string{
 			wsid + gateway.AuthMiddlewareSuffix,
 			wsid + gateway.StripPrefixMiddlewareSuffix,
 			wsid + gateway.HeadersMiddlewareSuffix,
-			wsid + gateway.ErrorsMiddlewareSuffix}
+			wsid + gateway.ErrorsMiddlewareSuffix,
+			wsid + gateway.RetryMiddlewareSuffix}
 		for _, mware := range mwares {
 			assert.Contains(t, workspaceMainConfig.HTTP.Middlewares, mware)
 
@@ -322,12 +323,15 @@ func TestCreateRelocatedObjectsK8S(t *testing.T) {
 			assert.Truef(t, found, "traefik config route doesn't set middleware '%s'", mware)
 		}
 
-		t.Run("testServerTransportIsEmpty", func(t *testing.T) {
-			assert.Empty(t, workspaceMainConfig.HTTP.ServersTransports)
+		t.Run("testServerTransportInMainWorkspaceRoute", func(t *testing.T) {
+			serverTransportName := wsid
+
+			assert.Len(t, workspaceMainConfig.HTTP.ServersTransports, 1)
+			assert.Contains(t, workspaceMainConfig.HTTP.ServersTransports, serverTransportName)
 
 			assert.Len(t, workspaceMainConfig.HTTP.Services, 1)
 			assert.Contains(t, workspaceMainConfig.HTTP.Services, wsid)
-			assert.Empty(t, workspaceMainConfig.HTTP.Services[wsid].LoadBalancer.ServersTransport)
+			assert.Equal(t, workspaceMainConfig.HTTP.Services[wsid].LoadBalancer.ServersTransport, serverTransportName)
 		})
 
 		t.Run("testHealthzEndpointInMainWorkspaceRoute", func(t *testing.T) {
@@ -402,7 +406,7 @@ func TestCreateRelocatedObjectsOpenshift(t *testing.T) {
 
 		workspaceMainConfig := gateway.TraefikConfig{}
 		assert.NoError(t, yaml.Unmarshal([]byte(traefikMainWorkspaceConfig), &workspaceMainConfig))
-		assert.Len(t, workspaceMainConfig.HTTP.Middlewares, 5)
+		assert.Len(t, workspaceMainConfig.HTTP.Middlewares, 6)
 
 		wsid = "wsid"
 		mwares := []string{
@@ -410,7 +414,8 @@ func TestCreateRelocatedObjectsOpenshift(t *testing.T) {
 			wsid + gateway.StripPrefixMiddlewareSuffix,
 			wsid + gateway.HeaderRewriteMiddlewareSuffix,
 			wsid + gateway.HeadersMiddlewareSuffix,
-			wsid + gateway.ErrorsMiddlewareSuffix}
+			wsid + gateway.ErrorsMiddlewareSuffix,
+			wsid + gateway.RetryMiddlewareSuffix}
 		for _, mware := range mwares {
 			assert.Contains(t, workspaceMainConfig.HTTP.Middlewares, mware)
 
