@@ -18,19 +18,6 @@ import (
 )
 
 const (
-	// PostgresSQL
-	DefaultPostgresUser              = "pgche"
-	DefaultPostgresHostName          = "postgres"
-	DefaultPostgresPort              = "5432"
-	DefaultPostgresDb                = "dbche"
-	DefaultPostgresMemoryLimit       = "1024Mi"
-	DefaultPostgresMemoryRequest     = "512Mi"
-	DefaultPostgresCpuLimit          = "500m"
-	DefaultPostgresCpuRequest        = "100m"
-	DefaultPostgresCredentialsSecret = "postgres-credentials"
-	DefaultPostgresVolumeClaimName   = "postgres-data"
-	DefaultPostgresPvcClaimSize      = "1Gi"
-
 	// Dashboard
 	DefaultDashboardMemoryLimit   = "256Mi"
 	DefaultDashboardMemoryRequest = "32Mi"
@@ -44,7 +31,6 @@ const (
 	DefaultPluginRegistryMemoryRequestEmbeddedOpenVSXRegistry = "512Mi"
 	DefaultPluginRegistryCpuLimit                             = "500m"
 	DefaultPluginRegistryCpuRequest                           = "100m"
-	DefaultOpenVSXUrl                                         = "https://open-vsx.org"
 
 	// DevfileRegistry
 	DefaultDevfileRegistryMemoryLimit   = "256Mi"
@@ -98,13 +84,14 @@ const (
 	KubernetesNameLabelKey      = "app.kubernetes.io/name"
 
 	// Annotations
-	CheEclipseOrgMountPath                = "che.eclipse.org/mount-path"
-	CheEclipseOrgMountAs                  = "che.eclipse.org/mount-as"
-	CheEclipseOrgEnvName                  = "che.eclipse.org/env-name"
-	CheEclipseOrgNamespace                = "che.eclipse.org/namespace"
-	CheEclipseOrgOAuthScmServer           = "che.eclipse.org/oauth-scm-server"
-	CheEclipseOrgScmServerEndpoint        = "che.eclipse.org/scm-server-endpoint"
-	CheEclipseOrgManagedAnnotationsDigest = "che.eclipse.org/managed-annotations-digest"
+	CheEclipseOrgMountPath                          = "che.eclipse.org/mount-path"
+	CheEclipseOrgMountAs                            = "che.eclipse.org/mount-as"
+	CheEclipseOrgEnvName                            = "che.eclipse.org/env-name"
+	CheEclipseOrgNamespace                          = "che.eclipse.org/namespace"
+	CheEclipseOrgOAuthScmServer                     = "che.eclipse.org/oauth-scm-server"
+	CheEclipseOrgScmServerEndpoint                  = "che.eclipse.org/scm-server-endpoint"
+	CheEclipseOrgManagedAnnotationsDigest           = "che.eclipse.org/managed-annotations-digest"
+	CheEclipseOrgScmGitHubDisableSubdomainIsolation = "che.eclipse.org/scm-github-disable-subdomain-isolation"
 
 	// DevEnvironments
 	PerUserPVCStorageStrategy      = "per-user"
@@ -126,7 +113,6 @@ const (
 	// components name
 	DevfileRegistryName                = "devfile-registry"
 	PluginRegistryName                 = "plugin-registry"
-	PostgresName                       = "postgres"
 	GatewayContainerName               = "gateway"
 	GatewayConfigSideCarContainerName  = "configbump"
 	GatewayAuthenticationContainerName = "oauth-proxy"
