@@ -16,34 +16,39 @@ import (
 	"os"
 	"strings"
 
+	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
+	"k8s.io/apimachinery/pkg/runtime"
+
 	"github.com/devfile/devworkspace-operator/pkg/infrastructure"
-	chev2 "github.com/eclipse-che/che-operator/api/v2"
 	util "github.com/eclipse-che/che-operator/pkg/common/utils"
 	"github.com/sirupsen/logrus"
 	appsv1 "k8s.io/api/apps/v1"
 )
 
 var (
-	defaultCheVersion                             string
-	defaultCheFlavor                              string
-	defaultCheServerImage                         string
-	defaultDashboardImage                         string
-	defaultPluginRegistryImage                    string
-	defaultDevfileRegistryImage                   string
-	defaultCheTLSSecretsCreationJobImage          string
-	defaultPostgresImage                          string
-	defaultPostgres13Image                        string
-	defaultSingleHostGatewayImage                 string
-	defaultSingleHostGatewayConfigSidecarImage    string
-	defaultGatewayAuthenticationSidecarImage      string
-	defaultGatewayAuthorizationSidecarImage       string
-	defaultCheWorkspacePluginBrokerMetadataImage  string
-	defaultCheWorkspacePluginBrokerArtifactsImage string
-	defaultCheServerSecureExposerJwtProxyImage    string
-	defaultConsoleLinkName                        string
-	defaultConsoleLinkDisplayName                 string
-	defaultConsoleLinkSection                     string
-	defaultsConsoleLinkImage                      string
+	defaultCheVersion                                       string
+	defaultCheFlavor                                        string
+	defaultCheServerImage                                   string
+	defaultDashboardImage                                   string
+	defaultPluginRegistryImage                              string
+	defaultDevfileRegistryImage                             string
+	defaultCheTLSSecretsCreationJobImage                    string
+	defaultSingleHostGatewayImage                           string
+	defaultSingleHostGatewayConfigSidecarImage              string
+	defaultGatewayAuthenticationSidecarImage                string
+	defaultGatewayAuthorizationSidecarImage                 string
+	defaultCheWorkspacePluginBrokerMetadataImage            string
+	defaultCheWorkspacePluginBrokerArtifactsImage           string
+	defaultCheServerSecureExposerJwtProxyImage              string
+	defaultConsoleLinkName                                  string
+	defaultConsoleLinkDisplayName                           string
+	defaultConsoleLinkSection                               string
+	defaultsConsoleLinkImage                                string
+	defaultDevEnvironmentsDefaultEditor                     string
+	defaultDevEnvironmentsDefaultComponents                 string
+	defaultDevEnvironmentsDisableContainerBuildCapabilities string
+	defaultPluginRegistryOpenVSXURL                         string
+	defaultDashboardHeaderMessageText                       string
 
 	initialized = false
 )
@@ -56,9 +61,7 @@ func InitializeForTesting(operatorDeploymentFilePath string) {
 
 	for _, container := range operatorDeployment.Spec.Template.Spec.Containers {
 		for _, env := range container.Env {
-			if env.Value != "" {
-				os.Setenv(env.Name, env.Value)
-			}
+			os.Setenv(env.Name, env.Value)
 		}
 	}
 
@@ -73,16 +76,18 @@ func Initialize() {
 	defaultConsoleLinkSection = ensureEnv("CONSOLE_LINK_SECTION")
 	defaultsConsoleLinkImage = ensureEnv("CONSOLE_LINK_IMAGE")
 
+	defaultDevEnvironmentsDisableContainerBuildCapabilities = ensureEnv("CHE_DEFAULT_SPEC_DEVENVIRONMENTS_DISABLECONTAINERBUILDCAPABILITIES")
+	defaultDevEnvironmentsDefaultComponents = ensureEnv("CHE_DEFAULT_SPEC_DEVENVIRONMENTS_DEFAULTCOMPONENTS")
+
+	// can be empty
+	defaultDevEnvironmentsDefaultEditor = os.Getenv("CHE_DEFAULT_SPEC_DEVENVIRONMENTS_DEFAULTEDITOR")
+	defaultPluginRegistryOpenVSXURL = os.Getenv("CHE_DEFAULT_SPEC_COMPONENTS_PLUGINREGISTRY_OPENVSXURL")
+	defaultDashboardHeaderMessageText = os.Getenv("CHE_DEFAULT_SPEC_COMPONENTS_DASHBOARD_HEADERMESSAGE_TEXT")
+
 	defaultCheServerImage = ensureEnv(util.GetArchitectureDependentEnvName("RELATED_IMAGE_che_server"))
 	defaultDashboardImage = ensureEnv(util.GetArchitectureDependentEnvName("RELATED_IMAGE_dashboard"))
 	defaultPluginRegistryImage = ensureEnv(util.GetArchitectureDependentEnvName("RELATED_IMAGE_plugin_registry"))
 	defaultDevfileRegistryImage = ensureEnv(util.GetArchitectureDependentEnvName("RELATED_IMAGE_devfile_registry"))
-	defaultPostgresImage = ensureEnv(util.GetArchitectureDependentEnvName("RELATED_IMAGE_postgres"))
-
-	// allow not to set env variable into a container
-	// while downstream is not migrated to PostgreSQL 13.3 yet
-	defaultPostgres13Image = os.Getenv(util.GetArchitectureDependentEnvName("RELATED_IMAGE_postgres_13_3"))
-
 	defaultSingleHostGatewayImage = ensureEnv(util.GetArchitectureDependentEnvName("RELATED_IMAGE_single_host_gateway"))
 	defaultSingleHostGatewayConfigSidecarImage = ensureEnv(util.GetArchitectureDependentEnvName("RELATED_IMAGE_single_host_gateway_config_sidecar"))
 	defaultGatewayAuthenticationSidecarImage = ensureEnv(util.GetArchitectureDependentEnvName("RELATED_IMAGE_gateway_authentication_sidecar"))
@@ -107,7 +112,7 @@ func ensureEnv(name string) string {
 	return value
 }
 
-func GetCheServerImage(checluster *chev2.CheCluster) string {
+func GetCheServerImage(checluster interface{}) string {
 	if !initialized {
 		logrus.Fatalf("Operator defaults are not initialized.")
 	}
@@ -131,23 +136,7 @@ func GetCheVersion() string {
 	return defaultCheVersion
 }
 
-func GetPostgresImage(checluster *chev2.CheCluster) string {
-	if !initialized {
-		logrus.Fatalf("Operator defaults are not initialized.")
-	}
-
-	return PatchDefaultImageName(checluster, defaultPostgresImage)
-}
-
-func GetPostgres13Image(checluster *chev2.CheCluster) string {
-	if !initialized {
-		logrus.Fatalf("Operator defaults are not initialized.")
-	}
-
-	return PatchDefaultImageName(checluster, defaultPostgres13Image)
-}
-
-func GetDashboardImage(checluster *chev2.CheCluster) string {
+func GetDashboardImage(checluster interface{}) string {
 	if !initialized {
 		logrus.Fatalf("Operator defaults are not initialized.")
 	}
@@ -155,7 +144,7 @@ func GetDashboardImage(checluster *chev2.CheCluster) string {
 	return PatchDefaultImageName(checluster, defaultDashboardImage)
 }
 
-func GetPluginRegistryImage(checluster *chev2.CheCluster) string {
+func GetPluginRegistryImage(checluster interface{}) string {
 	if !initialized {
 		logrus.Fatalf("Operator defaults are not initialized.")
 	}
@@ -163,7 +152,7 @@ func GetPluginRegistryImage(checluster *chev2.CheCluster) string {
 	return PatchDefaultImageName(checluster, defaultPluginRegistryImage)
 }
 
-func GetDevfileRegistryImage(checluster *chev2.CheCluster) string {
+func GetDevfileRegistryImage(checluster interface{}) string {
 	if !initialized {
 		logrus.Fatalf("Operator defaults are not initialized.")
 	}
@@ -171,7 +160,7 @@ func GetDevfileRegistryImage(checluster *chev2.CheCluster) string {
 	return PatchDefaultImageName(checluster, defaultDevfileRegistryImage)
 }
 
-func GetCheWorkspacePluginBrokerMetadataImage(checluster *chev2.CheCluster) string {
+func GetCheWorkspacePluginBrokerMetadataImage(checluster interface{}) string {
 	if !initialized {
 		logrus.Fatalf("Operator defaults are not initialized.")
 	}
@@ -179,7 +168,7 @@ func GetCheWorkspacePluginBrokerMetadataImage(checluster *chev2.CheCluster) stri
 	return PatchDefaultImageName(checluster, defaultCheWorkspacePluginBrokerMetadataImage)
 }
 
-func GetCheWorkspacePluginBrokerArtifactsImage(checluster *chev2.CheCluster) string {
+func GetCheWorkspacePluginBrokerArtifactsImage(checluster interface{}) string {
 	if !initialized {
 		logrus.Fatalf("Operator defaults are not initialized.")
 	}
@@ -187,7 +176,7 @@ func GetCheWorkspacePluginBrokerArtifactsImage(checluster *chev2.CheCluster) str
 	return PatchDefaultImageName(checluster, defaultCheWorkspacePluginBrokerArtifactsImage)
 }
 
-func GetCheServerSecureExposerJwtProxyImage(checluster *chev2.CheCluster) string {
+func GetCheServerSecureExposerJwtProxyImage(checluster interface{}) string {
 	if !initialized {
 		logrus.Fatalf("Operator defaults are not initialized.")
 	}
@@ -195,7 +184,7 @@ func GetCheServerSecureExposerJwtProxyImage(checluster *chev2.CheCluster) string
 	return PatchDefaultImageName(checluster, defaultCheServerSecureExposerJwtProxyImage)
 }
 
-func GetGatewayImage(checluster *chev2.CheCluster) string {
+func GetGatewayImage(checluster interface{}) string {
 	if !initialized {
 		logrus.Fatalf("Operator defaults are not initialized.")
 	}
@@ -203,7 +192,7 @@ func GetGatewayImage(checluster *chev2.CheCluster) string {
 	return PatchDefaultImageName(checluster, defaultSingleHostGatewayImage)
 }
 
-func GetGatewayConfigSidecarImage(checluster *chev2.CheCluster) string {
+func GetGatewayConfigSidecarImage(checluster interface{}) string {
 	if !initialized {
 		logrus.Fatalf("Operator defaults are not initialized.")
 	}
@@ -211,7 +200,7 @@ func GetGatewayConfigSidecarImage(checluster *chev2.CheCluster) string {
 	return PatchDefaultImageName(checluster, defaultSingleHostGatewayConfigSidecarImage)
 }
 
-func GetGatewayAuthenticationSidecarImage(checluster *chev2.CheCluster) string {
+func GetGatewayAuthenticationSidecarImage(checluster interface{}) string {
 	if !initialized {
 		logrus.Fatalf("Operator defaults are not initialized.")
 	}
@@ -219,7 +208,7 @@ func GetGatewayAuthenticationSidecarImage(checluster *chev2.CheCluster) string {
 	return PatchDefaultImageName(checluster, defaultGatewayAuthenticationSidecarImage)
 }
 
-func GetGatewayAuthorizationSidecarImage(checluster *chev2.CheCluster) string {
+func GetGatewayAuthorizationSidecarImage(checluster interface{}) string {
 	if !initialized {
 		logrus.Fatalf("Operator defaults are not initialized.")
 	}
@@ -235,10 +224,6 @@ func GetCheFlavor() string {
 	return defaultCheFlavor
 }
 
-func IsComponentReadinessInitContainersConfigured() bool {
-	return os.Getenv("ADD_COMPONENT_READINESS_INIT_CONTAINERS") == "true"
-}
-
 func GetConsoleLinkName() string {
 	if !initialized {
 		logrus.Fatalf("Operator defaults are not initialized.")
@@ -271,29 +256,68 @@ func GetConsoleLinkImage() string {
 	return defaultsConsoleLinkImage
 }
 
-func PatchDefaultImageName(checluster *chev2.CheCluster, imageName string) string {
-	if !checluster.IsAirGapMode() {
+func GetPluginRegistryOpenVSXURL() string {
+	if !initialized {
+		logrus.Fatalf("Operator defaults are not initialized.")
+	}
+
+	return defaultPluginRegistryOpenVSXURL
+}
+
+func GetDashboardHeaderMessageText() string {
+	if !initialized {
+		logrus.Fatalf("Operator defaults are not initialized.")
+	}
+
+	return defaultDashboardHeaderMessageText
+}
+
+func GetDevEnvironmentsDefaultEditor() string {
+	if !initialized {
+		logrus.Fatalf("Operator defaults are not initialized.")
+	}
+
+	return defaultDevEnvironmentsDefaultEditor
+}
+
+func GetDevEnvironmentsDefaultComponents() string {
+	if !initialized {
+		logrus.Fatalf("Operator defaults are not initialized.")
+	}
+
+	return defaultDevEnvironmentsDefaultComponents
+}
+
+func GetDevEnvironmentsDisableContainerBuildCapabilities() string {
+	if !initialized {
+		logrus.Fatalf("Operator defaults are not initialized.")
+	}
+
+	return defaultDevEnvironmentsDisableContainerBuildCapabilities
+}
+
+func PatchDefaultImageName(checluster interface{}, imageName string) string {
+	checlusterUnstructured, _ := runtime.DefaultUnstructuredConverter.ToUnstructured(checluster)
+	hostname, _, _ := unstructured.NestedString(checlusterUnstructured, "spec", "containerRegistry", "hostname")
+	organization, _, _ := unstructured.NestedString(checlusterUnstructured, "spec", "containerRegistry", "organization")
+
+	if hostname == "" && organization == "" {
 		return imageName
 	}
 
-	var hostname, organization string
-	if checluster.Spec.ContainerRegistry.Hostname != "" {
-		hostname = checluster.Spec.ContainerRegistry.Hostname
-	} else {
+	if hostname == "" {
 		hostname = getHostnameFromImage(imageName)
 	}
 
-	if checluster.Spec.ContainerRegistry.Organization != "" {
-		organization = checluster.Spec.ContainerRegistry.Organization
-	} else {
+	if organization == "" {
 		organization = getOrganizationFromImage(imageName)
 	}
 
-	image := getImageNameFromFullImage(imageName)
+	image := GetImageNameFromFullImage(imageName)
 	return fmt.Sprintf("%s/%s/%s", hostname, organization, image)
 }
 
-func getImageNameFromFullImage(image string) string {
+func GetImageNameFromFullImage(image string) string {
 	imageParts := strings.Split(image, "/")
 	nameAndTag := ""
 	switch len(imageParts) {
