@@ -19,9 +19,6 @@ import (
 	"strings"
 	"time"
 
-	"github.com/devfile/devworkspace-operator/pkg/infrastructure"
-	"github.com/eclipse-che/che-operator/pkg/common/test"
-
 	"k8s.io/apimachinery/pkg/labels"
 
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -236,11 +233,3 @@ func Whitelist(hostname string) (value string) {
 	}
 	return hostname
 }
-
-func GetOperatorNamespace() (string, error) {
-	if test.IsTestMode() {
-		return "eclipse-che", nil
-	}
-
-	return infrastructure.GetOperatorNamespace()
-}
