@@ -351,12 +351,17 @@ func (c *WorkspacePermissionsReconciler) getWorkspacesPolicies() []rbacv1.Policy
 			Resources: []string{"namespaces"},
 			Verbs:     []string{"get", "list"},
 		},
+		{
+			APIGroups: []string{""},
+			Resources: []string{"events"},
+			Verbs:     []string{"watch", "list"},
+		},
 	}
 	openshiftPolicies := []rbacv1.PolicyRule{
 		{
 			APIGroups: []string{"route.openshift.io"},
 			Resources: []string{"routes"},
-			Verbs:     []string{"list", "create", "delete"},
+			Verbs:     []string{"get", "list", "create", "delete"},
 		},
 		{
 			APIGroups: []string{"authorization.openshift.io"},
